@@ -1,4 +1,5 @@
 import logging
+from typing import Optional
 
 from .order_builder.builder import OrderBuilder
 from .headers.headers import create_level_1_headers, create_level_2_headers
@@ -14,6 +15,7 @@ from .endpoints import (
     DELETE_API_KEY,
     DERIVE_API_KEY,
     GET_API_KEYS,
+    CLOSED_ONLY,
     GET_LAST_TRADE_PRICE,
     GET_ORDER,
     GET_ORDER_BOOK,
@@ -29,6 +31,7 @@ from .endpoints import (
     UPDATE_BALANCE_ALLOWANCE,
     IS_ORDER_SCORING,
     GET_TICK_SIZE,
+    GET_NEG_RISK,
     ARE_ORDERS_SCORING,
     GET_SIMPLIFIED_MARKETS,
     GET_MARKETS,
@@ -115,7 +118,11 @@ class ClobClient:
             self.builder = OrderBuilder(
                 self.signer, sig_type=signature_type, funder=funder
             )
+
+        # local cache
         self.__tick_sizes = {}
+        self.__neg_risk = {}
+
         self.logger = logging.getLogger(self.__class__.__name__)
 
     def get_address(self):
@@ -231,6 +238,17 @@ class ClobClient:
         headers = create_level_2_headers(self.signer, self.creds, request_args)
         return get("{}{}".format(self.host, GET_API_KEYS), headers=headers)
 
+    def get_closed_only_mode(self):
+        """
+        Gets the closed only mode flag for thsi address
+        Level 2 Auth required
+        """
+        self.assert_level_2_auth()
+
+        request_args = RequestArgs(method="GET", request_path=CLOSED_ONLY)
+        headers = create_level_2_headers(self.signer, self.creds, request_args)
+        return get("{}{}".format(self.host, CLOSED_ONLY), headers=headers)
+
     def delete_api_key(self):
         """
         Deletes an API key
@@ -290,6 +308,15 @@ class ClobClient:
 
         return self.__tick_sizes[token_id]
 
+    def get_neg_risk(self, token_id: str) -> bool:
+        if token_id in self.__neg_risk:
+            return self.__neg_risk[token_id]
+
+        result = get("{}{}?token_id={}".format(self.host, GET_NEG_RISK, token_id))
+        self.__neg_risk[token_id] = result["neg_risk"]
+
+        return result["neg_risk"]
+
     def __resolve_tick_size(
         self, token_id: str, tick_size: TickSize = None
     ) -> TickSize:
@@ -307,7 +334,7 @@ class ClobClient:
         return tick_size
 
     def create_order(
-        self, order_args: OrderArgs, options: PartialCreateOrderOptions = None
+        self, order_args: OrderArgs, options: Optional[PartialCreateOrderOptions] = None
     ):
         """
         Creates and signs an order
@@ -320,7 +347,6 @@ class ClobClient:
             order_args.token_id,
             options.tick_size if options else None,
         )
-        neg_risk = options.neg_risk if options else False
 
         if not price_valid(order_args.price, tick_size):
             raise Exception(
@@ -332,6 +358,12 @@ class ClobClient:
                 + str(1 - float(tick_size))
             )
 
+        neg_risk = (
+            options.neg_risk
+            if options and options.neg_risk
+            else self.get_neg_risk(order_args.token_id)
+        )
+
         return self.builder.create_order(
             order_args,
             CreateOrderOptions(
@@ -341,7 +373,9 @@ class ClobClient:
         )
 
     def create_market_order(
-        self, order_args: MarketOrderArgs, options: PartialCreateOrderOptions = None
+        self,
+        order_args: MarketOrderArgs,
+        options: Optional[PartialCreateOrderOptions] = None,
     ):
         """
         Creates and signs an order
@@ -354,11 +388,10 @@ class ClobClient:
             order_args.token_id,
             options.tick_size if options else None,
         )
-        neg_risk = options.neg_risk if options else False
 
         if order_args.price is None or order_args.price <= 0:
             order_args.price = self.calculate_market_price(
-                order_args.token_id, "BUY", order_args.amount
+                order_args.token_id, order_args.side, order_args.amount
             )
 
         if not price_valid(order_args.price, tick_size):
@@ -371,6 +404,12 @@ class ClobClient:
                 + str(1 - float(tick_size))
             )
 
+        neg_risk = (
+            options.neg_risk
+            if options and options.neg_risk
+            else self.get_neg_risk(order_args.token_id)
+        )
+
         return self.builder.create_market_order(
             order_args,
             CreateOrderOptions(
@@ -701,8 +740,8 @@ class ClobClient:
         if side == "BUY":
             if book.asks is None:
                 raise Exception("no match")
-            return self.builder.calculate_market_price(book.asks, amount)
+            return self.builder.calculate_buy_market_price(book.asks, amount)
         else:
             if book.bids is None:
                 raise Exception("no match")
-            return self.builder.calculate_market_price(book.bids, amount)
+            return self.builder.calculate_sell_market_price(book.bids, amount)
