@@ -1,4 +1,3 @@
-from dataclasses import dataclass
 from typing import Any
 from dataclasses import dataclass, asdict
 from json import dumps
@@ -79,7 +78,13 @@ class MarketOrderArgs:
 
     amount: float
     """
-    Amount in terms of Collateral
+    BUY orders: $$$ Amount to buy
+    SELL orders: Shares to sell
+    """
+
+    side: str
+    """
+    Side of the order
     """
 
     price: float = 0
@@ -143,6 +148,7 @@ class OrderSummary:
 class OrderBookSummary:
     market: str = None
     asset_id: str = None
+    timestamp: str = None
     bids: list[OrderSummary] = None
     asks: list[OrderSummary] = None
     hash: str = None
@@ -190,13 +196,13 @@ TickSize = Literal["0.1", "0.01", "0.001", "0.0001"]
 @dataclass
 class CreateOrderOptions:
     tick_size: TickSize
-    neg_risk: bool = False
+    neg_risk: bool
 
 
 @dataclass
 class PartialCreateOrderOptions:
     tick_size: Optional[TickSize] = None
-    neg_risk: bool = False
+    neg_risk: Optional[bool] = None
 
 
 @dataclass
