@@ -16,5 +16,7 @@ L2_AUTH_UNAVAILABLE = "API Credentials are needed to interact with this endpoint
 
 ZERO_ADDRESS = "0x0000000000000000000000000000000000000000"
 
-MUMBAI = 80001
+AMOY = 80002
 POLYGON = 137
+
+END_CURSOR = "LTE="
