@@ -3,6 +3,7 @@ CREATE_API_KEY = "/auth/api-key"
 GET_API_KEYS = "/auth/api-keys"
 DELETE_API_KEY = "/auth/api-key"
 DERIVE_API_KEY = "/auth/derive-api-key"
+CLOSED_ONLY = "/auth/ban-status/closed-only"
 TRADES = "/data/trades"
 GET_ORDER_BOOK = "/book"
 GET_ORDER_BOOKS = "/books"
@@ -28,6 +29,7 @@ UPDATE_BALANCE_ALLOWANCE = "/balance-allowance/update"
 IS_ORDER_SCORING = "/order-scoring"
 ARE_ORDERS_SCORING = "/orders-scoring"
 GET_TICK_SIZE = "/tick-size"
+GET_NEG_RISK = "/neg-risk"
 GET_SAMPLING_SIMPLIFIED_MARKETS = "/sampling-simplified-markets"
 GET_SAMPLING_MARKETS = "/sampling-markets"
 GET_SIMPLIFIED_MARKETS = "/simplified-markets"
