@@ -82,21 +82,38 @@ class OrderBuilder:
             raise ValueError(f"order_args.side must be '{BUY}' or '{SELL}'")
 
     def get_market_order_amounts(
-        self, amount: float, price: float, round_config: RoundConfig
+        self, side: str, amount: float, price: float, round_config: RoundConfig
     ):
-        raw_maker_amt = round_down(amount, round_config.size)
         raw_price = round_normal(price, round_config.price)
 
-        raw_taker_amt = raw_maker_amt / raw_price
-        if decimal_places(raw_taker_amt) > round_config.amount:
-            raw_taker_amt = round_up(raw_taker_amt, round_config.amount + 4)
+        if side == BUY:
+            raw_maker_amt = round_down(amount, round_config.size)
+            raw_taker_amt = raw_maker_amt / raw_price
             if decimal_places(raw_taker_amt) > round_config.amount:
-                raw_taker_amt = round_down(raw_taker_amt, round_config.amount)
+                raw_taker_amt = round_up(raw_taker_amt, round_config.amount + 4)
+                if decimal_places(raw_taker_amt) > round_config.amount:
+                    raw_taker_amt = round_down(raw_taker_amt, round_config.amount)
 
-        maker_amount = to_token_decimals(raw_maker_amt)
-        taker_amount = to_token_decimals(raw_taker_amt)
+            maker_amount = to_token_decimals(raw_maker_amt)
+            taker_amount = to_token_decimals(raw_taker_amt)
 
-        return maker_amount, taker_amount
+            return UtilsBuy, maker_amount, taker_amount
+
+        elif side == SELL:
+            raw_maker_amt = round_down(amount, round_config.size)
+
+            raw_taker_amt = raw_maker_amt * raw_price
+            if decimal_places(raw_taker_amt) > round_config.amount:
+                raw_taker_amt = round_up(raw_taker_amt, round_config.amount + 4)
+                if decimal_places(raw_taker_amt) > round_config.amount:
+                    raw_taker_amt = round_down(raw_taker_amt, round_config.amount)
+
+            maker_amount = to_token_decimals(raw_maker_amt)
+            taker_amount = to_token_decimals(raw_taker_amt)
+
+            return UtilsSell, maker_amount, taker_amount
+        else:
+            raise ValueError(f"order_args.side must be '{BUY}' or '{SELL}'")
 
     def create_order(
         self, order_args: OrderArgs, options: CreateOrderOptions
@@ -143,7 +160,8 @@ class OrderBuilder:
         """
         Creates and signs a market order
         """
-        maker_amount, taker_amount = self.get_market_order_amounts(
+        side, maker_amount, taker_amount = self.get_market_order_amounts(
+            order_args.side,
             order_args.amount,
             order_args.price,
             ROUNDING_CONFIG[options.tick_size],
@@ -155,7 +173,7 @@ class OrderBuilder:
             tokenId=order_args.token_id,
             makerAmount=str(maker_amount),
             takerAmount=str(taker_amount),
-            side=UtilsBuy,
+            side=side,
             feeRateBps=str(order_args.fee_rate_bps),
             nonce=str(order_args.nonce),
             signer=self.signer.address(),
@@ -175,7 +193,7 @@ class OrderBuilder:
 
         return order_builder.build_signed_order(data)
 
-    def calculate_market_price(
+    def calculate_buy_market_price(
         self, positions: list[OrderSummary], amount_to_match: float
     ) -> float:
         sum = 0
@@ -184,3 +202,13 @@ class OrderBuilder:
             if sum >= amount_to_match:
                 return float(p.price)
         raise Exception("no match")
+
+    def calculate_sell_market_price(
+        self, positions: list[OrderSummary], amount_to_match: float
+    ) -> float:
+        sum = 0
+        for p in reversed(positions):
+            sum += float(p.size)
+            if sum >= amount_to_match:
+                return float(p.price)
+        raise Exception("no match")
