@@ -1,4 +1,4 @@
-from eip712_structs import EIP712Struct, Address, String, Uint
+from poly_eip712_structs import EIP712Struct, Address, String, Uint
 
 
 class ClobAuth(EIP712Struct):
