@@ -12,7 +12,12 @@ from py_clob_client.order_builder.constants import BUY, SELL
 from py_clob_client.signer import Signer
 from py_clob_client.order_builder.builder import OrderBuilder, ROUNDING_CONFIG
 from py_clob_client.order_builder.helpers import decimal_places, round_normal
-from py_order_utils.model import POLY_GNOSIS_SAFE, EOA
+from py_order_utils.model import (
+    POLY_GNOSIS_SAFE,
+    EOA,
+    BUY as UtilsBuy,
+    SELL as UtilsSell,
+)
 
 # publicly known private key
 private_key = "0xac0974bec39a17e36ba4a6b4d238ff944bacb478cbed5efcae784d7bf4f2ff80"
@@ -21,11 +26,11 @@ signer = Signer(private_key=private_key, chain_id=chain_id)
 
 
 class TestOrderBuilder(TestCase):
-    def test_calculate_market_price_buy(self):
+    def test_calculate_buy_market_price(self):
         # empty
         with self.assertRaises(Exception):
             builder = OrderBuilder(signer)
-            builder.calculate_market_price([], 100)
+            builder.calculate_buy_market_price([], 100)
 
         # not enough
         with self.assertRaises(Exception):
@@ -34,7 +39,7 @@ class TestOrderBuilder(TestCase):
                 OrderSummary(price="0.4", size="100"),
             ]
             builder = OrderBuilder(signer)
-            builder.calculate_market_price(positions, 100)
+            builder.calculate_buy_market_price(positions, 100)
 
         # OK
         positions = [
@@ -43,7 +48,7 @@ class TestOrderBuilder(TestCase):
             OrderSummary(price="0.3", size="100"),
         ]
         builder = OrderBuilder(signer)
-        self.assertEqual(builder.calculate_market_price(positions, 100), 0.3)
+        self.assertEqual(builder.calculate_buy_market_price(positions, 100), 0.3)
 
         positions = [
             OrderSummary(price="0.5", size="100"),
@@ -51,7 +56,7 @@ class TestOrderBuilder(TestCase):
             OrderSummary(price="0.3", size="100"),
         ]
         builder = OrderBuilder(signer)
-        self.assertEqual(builder.calculate_market_price(positions, 100), 0.4)
+        self.assertEqual(builder.calculate_buy_market_price(positions, 100), 0.4)
 
         positions = [
             OrderSummary(price="0.5", size="120"),
@@ -59,7 +64,7 @@ class TestOrderBuilder(TestCase):
             OrderSummary(price="0.3", size="100"),
         ]
         builder = OrderBuilder(signer)
-        self.assertEqual(builder.calculate_market_price(positions, 100), 0.4)
+        self.assertEqual(builder.calculate_buy_market_price(positions, 100), 0.4)
 
         positions = [
             OrderSummary(price="0.5", size="200"),
@@ -67,22 +72,22 @@ class TestOrderBuilder(TestCase):
             OrderSummary(price="0.3", size="100"),
         ]
         builder = OrderBuilder(signer)
-        self.assertEqual(builder.calculate_market_price(positions, 100), 0.5)
+        self.assertEqual(builder.calculate_buy_market_price(positions, 100), 0.5)
 
-    def test_calculate_market_price_sell(self):
+    def test_calculate_sell_market_price(self):
         # empty
         with self.assertRaises(Exception):
             builder = OrderBuilder(signer)
-            builder.calculate_market_price([], 100)
+            builder.calculate_sell_market_price([], 100)
 
         # not enough
         with self.assertRaises(Exception):
             positions = [
-                OrderSummary(price="0.4", size="100"),
-                OrderSummary(price="0.5", size="100"),
+                OrderSummary(price="0.4", size="10"),
+                OrderSummary(price="0.5", size="10"),
             ]
             builder = OrderBuilder(signer)
-            builder.calculate_market_price(positions, 100)
+            builder.calculate_sell_market_price(positions, 100)
 
         # OK
         positions = [
@@ -91,23 +96,23 @@ class TestOrderBuilder(TestCase):
             OrderSummary(price="0.5", size="100"),
         ]
         builder = OrderBuilder(signer)
-        self.assertEqual(builder.calculate_market_price(positions, 100), 0.5)
+        self.assertEqual(builder.calculate_sell_market_price(positions, 100), 0.5)
 
         positions = [
             OrderSummary(price="0.3", size="100"),
             OrderSummary(price="0.4", size="300"),
-            OrderSummary(price="0.5", size="100"),
+            OrderSummary(price="0.5", size="10"),
         ]
         builder = OrderBuilder(signer)
-        self.assertEqual(builder.calculate_market_price(positions, 100), 0.4)
+        self.assertEqual(builder.calculate_sell_market_price(positions, 100), 0.4)
 
         positions = [
             OrderSummary(price="0.3", size="100"),
             OrderSummary(price="0.4", size="200"),
-            OrderSummary(price="0.5", size="100"),
+            OrderSummary(price="0.5", size="10"),
         ]
         builder = OrderBuilder(signer)
-        self.assertEqual(builder.calculate_market_price(positions, 100), 0.4)
+        self.assertEqual(builder.calculate_sell_market_price(positions, 100), 0.4)
 
         positions = [
             OrderSummary(price="0.3", size="300"),
@@ -115,7 +120,7 @@ class TestOrderBuilder(TestCase):
             OrderSummary(price="0.5", size="100"),
         ]
         builder = OrderBuilder(signer)
-        self.assertEqual(builder.calculate_market_price(positions, 100), 0.4)
+        self.assertEqual(builder.calculate_sell_market_price(positions, 200), 0.4)
 
         positions = [
             OrderSummary(price="0.3", size="334"),
@@ -123,9 +128,9 @@ class TestOrderBuilder(TestCase):
             OrderSummary(price="0.5", size="100"),
         ]
         builder = OrderBuilder(signer)
-        self.assertEqual(builder.calculate_market_price(positions, 100), 0.3)
+        self.assertEqual(builder.calculate_sell_market_price(positions, 300), 0.3)
 
-    def test_get_market_order_amounts_0_1(self):
+    def test_get_market_order_amounts_buy_0_1(self):
         builder = OrderBuilder(signer)
 
         delta_price = 0.1
@@ -134,9 +139,10 @@ class TestOrderBuilder(TestCase):
         while amount <= 1000:
             price = 0.1
             while price <= 1:
-                maker, taker = builder.get_market_order_amounts(
-                    amount, price, ROUNDING_CONFIG["0.1"]
+                side, maker, taker = builder.get_market_order_amounts(
+                    BUY, amount, price, ROUNDING_CONFIG["0.1"]
                 )
+                self.assertEqual(side, UtilsBuy)
                 self.assertEqual(decimal_places(maker), 0)
                 self.assertEqual(decimal_places(taker), 0)
                 self.assertGreaterEqual(
@@ -146,7 +152,7 @@ class TestOrderBuilder(TestCase):
 
             amount = amount + delta_size
 
-    def test_get_market_order_amounts_0_01(self):
+    def test_get_market_order_amounts_buy_0_01(self):
         builder = OrderBuilder(signer)
 
         delta_price = 0.01
@@ -155,9 +161,10 @@ class TestOrderBuilder(TestCase):
         while amount <= 100:
             price = 0.01
             while price <= 1:
-                maker, taker = builder.get_market_order_amounts(
-                    amount, price, ROUNDING_CONFIG["0.01"]
+                side, maker, taker = builder.get_market_order_amounts(
+                    BUY, amount, price, ROUNDING_CONFIG["0.01"]
                 )
+                self.assertEqual(side, UtilsBuy)
                 self.assertEqual(decimal_places(maker), 0)
                 self.assertEqual(decimal_places(taker), 0)
                 self.assertGreaterEqual(
@@ -167,7 +174,7 @@ class TestOrderBuilder(TestCase):
 
             amount = amount + delta_size
 
-    def test_get_market_order_amounts_0_001(self):
+    def test_get_market_order_amounts_buy_0_001(self):
         builder = OrderBuilder(signer)
 
         delta_price = 0.001
@@ -176,9 +183,10 @@ class TestOrderBuilder(TestCase):
         while amount <= 10:
             price = 0.001
             while price <= 1:
-                maker, taker = builder.get_market_order_amounts(
-                    amount, price, ROUNDING_CONFIG["0.001"]
+                side, maker, taker = builder.get_market_order_amounts(
+                    BUY, amount, price, ROUNDING_CONFIG["0.001"]
                 )
+                self.assertEqual(side, UtilsBuy)
                 self.assertEqual(decimal_places(maker), 0)
                 self.assertEqual(decimal_places(taker), 0)
                 self.assertGreaterEqual(
@@ -188,7 +196,7 @@ class TestOrderBuilder(TestCase):
 
             amount = amount + delta_size
 
-    def test_get_market_order_amounts_0_0001(self):
+    def test_get_market_order_amounts_buy_0_0001(self):
         builder = OrderBuilder(signer)
 
         delta_price = 0.0001
@@ -197,9 +205,10 @@ class TestOrderBuilder(TestCase):
         while amount <= 1:
             price = 0.0001
             while price <= 1:
-                maker, taker = builder.get_market_order_amounts(
-                    amount, price, ROUNDING_CONFIG["0.0001"]
+                side, maker, taker = builder.get_market_order_amounts(
+                    BUY, amount, price, ROUNDING_CONFIG["0.0001"]
                 )
+                self.assertEqual(side, UtilsBuy)
                 self.assertEqual(decimal_places(maker), 0)
                 self.assertEqual(decimal_places(taker), 0)
                 self.assertGreaterEqual(
@@ -209,6 +218,94 @@ class TestOrderBuilder(TestCase):
 
             amount = amount + delta_size
 
+    def test_get_market_order_amounts_sell_0_1(self):
+        builder = OrderBuilder(signer)
+
+        delta_price = 0.1
+        delta_size = 0.01
+        amount = 0.01
+        while amount <= 1000:
+            price = 0.1
+            while price <= 1:
+                side, maker, taker = builder.get_market_order_amounts(
+                    SELL, amount, price, ROUNDING_CONFIG["0.1"]
+                )
+                self.assertEqual(side, UtilsSell)
+                self.assertEqual(decimal_places(maker), 0)
+                self.assertEqual(decimal_places(taker), 0)
+                self.assertGreaterEqual(
+                    round_normal(maker / taker, 2), round_normal(price, 2)
+                )
+                price = price + delta_price
+
+            amount = amount + delta_size
+
+    def test_get_market_order_amounts_sell_0_01(self):
+        builder = OrderBuilder(signer)
+
+        delta_price = 0.01
+        delta_size = 0.01
+        amount = 0.01
+        while amount <= 100:
+            price = 0.01
+            while price <= 1:
+                side, maker, taker = builder.get_market_order_amounts(
+                    SELL, amount, price, ROUNDING_CONFIG["0.01"]
+                )
+                self.assertEqual(side, UtilsSell)
+                self.assertEqual(decimal_places(maker), 0)
+                self.assertEqual(decimal_places(taker), 0)
+                self.assertGreaterEqual(
+                    round_normal(maker / taker, 4), round_normal(price, 4)
+                )
+                price = price + delta_price
+
+            amount = amount + delta_size
+
+    def test_get_market_order_amounts_sell_0_001(self):
+        builder = OrderBuilder(signer)
+
+        delta_price = 0.001
+        delta_size = 0.01
+        amount = 0.01
+        while amount <= 10:
+            price = 0.001
+            while price <= 1:
+                side, maker, taker = builder.get_market_order_amounts(
+                    SELL, amount, price, ROUNDING_CONFIG["0.001"]
+                )
+                self.assertEqual(side, UtilsSell)
+                self.assertEqual(decimal_places(maker), 0)
+                self.assertEqual(decimal_places(taker), 0)
+                self.assertGreaterEqual(
+                    round_normal(maker / taker, 6), round_normal(price, 6)
+                )
+                price = price + delta_price
+
+            amount = amount + delta_size
+
+    def test_get_market_order_amounts_sell_0_0001(self):
+        builder = OrderBuilder(signer)
+
+        delta_price = 0.0001
+        delta_size = 0.01
+        amount = 0.01
+        while amount <= 1:
+            price = 0.0001
+            while price <= 1:
+                side, maker, taker = builder.get_market_order_amounts(
+                    SELL, amount, price, ROUNDING_CONFIG["0.0001"]
+                )
+                self.assertEqual(side, UtilsSell)
+                self.assertEqual(decimal_places(maker), 0)
+                self.assertEqual(decimal_places(taker), 0)
+                self.assertGreaterEqual(
+                    round_normal(taker / maker, 8), round_normal(price, 8)
+                )
+                price = price + delta_price
+
+            amount = amount + delta_size
+
     def test_get_order_amounts_buy_0_1(self):
         builder = OrderBuilder(signer)
 
@@ -396,7 +493,7 @@ class TestOrderBuilder(TestCase):
                 size=15,
                 side=BUY,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
         self.assertEqual(
             signed_order.order["makerAmount"],
@@ -415,7 +512,7 @@ class TestOrderBuilder(TestCase):
                 size=15,
                 side=SELL,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
         self.assertEqual(
             signed_order.order["makerAmount"],
@@ -434,7 +531,7 @@ class TestOrderBuilder(TestCase):
                 size=101,
                 side=BUY,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
         self.assertEqual(
             signed_order.order["makerAmount"],
@@ -453,7 +550,7 @@ class TestOrderBuilder(TestCase):
                 size=101,
                 side=SELL,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
         self.assertEqual(
             signed_order.order["makerAmount"],
@@ -472,7 +569,7 @@ class TestOrderBuilder(TestCase):
                 size=12.8205,
                 side=BUY,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
         self.assertEqual(
             signed_order.order["makerAmount"],
@@ -491,7 +588,7 @@ class TestOrderBuilder(TestCase):
                 size=12.8205,
                 side=SELL,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
         self.assertEqual(
             signed_order.order["makerAmount"],
@@ -510,7 +607,7 @@ class TestOrderBuilder(TestCase):
                 size=2435.89,
                 side=SELL,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
         self.assertEqual(
             signed_order.order["makerAmount"],
@@ -529,7 +626,7 @@ class TestOrderBuilder(TestCase):
                 size=19.1,
                 side=SELL,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
         self.assertEqual(
             signed_order.order["makerAmount"],
@@ -548,7 +645,7 @@ class TestOrderBuilder(TestCase):
                 size=18233.33,
                 side=BUY,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
         self.assertEqual(
             signed_order.order["makerAmount"],
@@ -575,7 +672,7 @@ class TestOrderBuilder(TestCase):
                 nonce=123,
                 expiration=50000,
             ),
-            options=CreateOrderOptions(tick_size="0.1"),
+            options=CreateOrderOptions(tick_size="0.1", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -644,7 +741,7 @@ class TestOrderBuilder(TestCase):
                 nonce=123,
                 expiration=50000,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -713,7 +810,7 @@ class TestOrderBuilder(TestCase):
                 nonce=123,
                 expiration=50000,
             ),
-            options=CreateOrderOptions(tick_size="0.001"),
+            options=CreateOrderOptions(tick_size="0.001", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -782,7 +879,7 @@ class TestOrderBuilder(TestCase):
                 nonce=123,
                 expiration=50000,
             ),
-            options=CreateOrderOptions(tick_size="0.0001"),
+            options=CreateOrderOptions(tick_size="0.0001", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -851,7 +948,7 @@ class TestOrderBuilder(TestCase):
                 nonce=123,
                 expiration=50000,
             ),
-            options=CreateOrderOptions(tick_size="0.1"),
+            options=CreateOrderOptions(tick_size="0.1", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -920,7 +1017,7 @@ class TestOrderBuilder(TestCase):
                 nonce=123,
                 expiration=50000,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -989,7 +1086,7 @@ class TestOrderBuilder(TestCase):
                 nonce=123,
                 expiration=50000,
             ),
-            options=CreateOrderOptions(tick_size="0.001"),
+            options=CreateOrderOptions(tick_size="0.001", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -1058,7 +1155,7 @@ class TestOrderBuilder(TestCase):
                 nonce=123,
                 expiration=50000,
             ),
-            options=CreateOrderOptions(tick_size="0.0001"),
+            options=CreateOrderOptions(tick_size="0.0001", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -1992,7 +2089,7 @@ class TestOrderBuilder(TestCase):
                 nonce=123,
                 expiration=50000,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
 
         self.assertIsNotNone(signed_order)
@@ -2060,7 +2157,7 @@ class TestOrderBuilder(TestCase):
                 nonce=123,
                 expiration=50000,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
 
         self.assertIsNotNone(signed_order)
@@ -2120,13 +2217,14 @@ class TestOrderBuilder(TestCase):
 
         signed_order = builder.create_market_order(
             order_args=MarketOrderArgs(
+                side=BUY,
                 token_id="123",
                 price=0.5,
                 amount=100,
                 fee_rate_bps=111,
                 nonce=123,
             ),
-            options=CreateOrderOptions(tick_size="0.1"),
+            options=CreateOrderOptions(tick_size="0.1", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -2187,13 +2285,14 @@ class TestOrderBuilder(TestCase):
 
         signed_order = builder.create_market_order(
             order_args=MarketOrderArgs(
+                side=BUY,
                 token_id="123",
                 price=0.56,
                 amount=100,
                 fee_rate_bps=111,
                 nonce=123,
             ),
-            options=CreateOrderOptions(tick_size="0.01"),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -2254,13 +2353,14 @@ class TestOrderBuilder(TestCase):
 
         signed_order = builder.create_market_order(
             order_args=MarketOrderArgs(
+                side=BUY,
                 token_id="123",
                 price=0.056,
                 amount=100,
                 fee_rate_bps=111,
                 nonce=123,
             ),
-            options=CreateOrderOptions(tick_size="0.001"),
+            options=CreateOrderOptions(tick_size="0.001", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -2321,13 +2421,14 @@ class TestOrderBuilder(TestCase):
 
         signed_order = builder.create_market_order(
             order_args=MarketOrderArgs(
+                side=BUY,
                 token_id="123",
                 price=0.0056,
                 amount=100,
                 fee_rate_bps=111,
                 nonce=123,
             ),
-            options=CreateOrderOptions(tick_size="0.0001"),
+            options=CreateOrderOptions(tick_size="0.0001", neg_risk=False),
         )
 
         self.assertTrue(isinstance(signed_order.order["salt"], int))
@@ -2388,6 +2489,7 @@ class TestOrderBuilder(TestCase):
 
         signed_order = builder.create_market_order(
             order_args=MarketOrderArgs(
+                side=BUY,
                 token_id="123",
                 price=0.5,
                 amount=100,
@@ -2455,6 +2557,7 @@ class TestOrderBuilder(TestCase):
 
         signed_order = builder.create_market_order(
             order_args=MarketOrderArgs(
+                side=BUY,
                 token_id="123",
                 price=0.56,
                 amount=100,
@@ -2522,6 +2625,7 @@ class TestOrderBuilder(TestCase):
 
         signed_order = builder.create_market_order(
             order_args=MarketOrderArgs(
+                side=BUY,
                 token_id="123",
                 price=0.056,
                 amount=100,
@@ -2589,6 +2693,7 @@ class TestOrderBuilder(TestCase):
 
         signed_order = builder.create_market_order(
             order_args=MarketOrderArgs(
+                side=BUY,
                 token_id="123",
                 price=0.0056,
                 amount=100,
@@ -2650,3 +2755,547 @@ class TestOrderBuilder(TestCase):
             / float(signed_order.order["takerAmount"]),
             0.0056,
         )
+
+    def test_create_market_order_sell_0_1(self):
+        builder = OrderBuilder(signer)
+
+        signed_order = builder.create_market_order(
+            order_args=MarketOrderArgs(
+                side=SELL,
+                token_id="123",
+                price=0.5,
+                amount=100,
+                fee_rate_bps=111,
+                nonce=123,
+            ),
+            options=CreateOrderOptions(tick_size="0.1", neg_risk=False),
+        )
+
+        self.assertTrue(isinstance(signed_order.order["salt"], int))
+        self.assertIsNotNone(signed_order)
+        self.assertEqual(
+            signed_order.order["maker"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["signer"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["taker"],
+            "0x0000000000000000000000000000000000000000",
+        )
+        self.assertEqual(
+            signed_order.order["tokenId"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["makerAmount"],
+            100000000,
+        )
+        self.assertEqual(
+            signed_order.order["takerAmount"],
+            50000000,
+        )
+        self.assertEqual(
+            signed_order.order["side"],
+            1,
+        )
+        self.assertEqual(
+            signed_order.order["expiration"],
+            0,
+        )
+        self.assertEqual(
+            signed_order.order["nonce"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["feeRateBps"],
+            111,
+        )
+        self.assertEqual(
+            signed_order.order["signatureType"],
+            EOA,
+        )
+        self.assertIsNotNone(signed_order.signature)
+        self.assertGreaterEqual(
+            float(signed_order.order["takerAmount"])
+            / float(signed_order.order["makerAmount"]),
+            0.5,
+        )
+
+    def test_create_market_order_sell_0_01(self):
+        builder = OrderBuilder(signer)
+
+        signed_order = builder.create_market_order(
+            order_args=MarketOrderArgs(
+                side=SELL,
+                token_id="123",
+                price=0.56,
+                amount=100,
+                fee_rate_bps=111,
+                nonce=123,
+            ),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=False),
+        )
+
+        self.assertTrue(isinstance(signed_order.order["salt"], int))
+        self.assertIsNotNone(signed_order)
+        self.assertEqual(
+            signed_order.order["maker"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["signer"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["taker"],
+            "0x0000000000000000000000000000000000000000",
+        )
+        self.assertEqual(
+            signed_order.order["tokenId"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["makerAmount"],
+            100000000,
+        )
+        self.assertEqual(
+            signed_order.order["takerAmount"],
+            56000000,
+        )
+        self.assertEqual(
+            signed_order.order["side"],
+            1,
+        )
+        self.assertEqual(
+            signed_order.order["expiration"],
+            0,
+        )
+        self.assertEqual(
+            signed_order.order["nonce"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["feeRateBps"],
+            111,
+        )
+        self.assertEqual(
+            signed_order.order["signatureType"],
+            EOA,
+        )
+        self.assertIsNotNone(signed_order.signature)
+        self.assertGreaterEqual(
+            float(signed_order.order["takerAmount"])
+            / float(signed_order.order["makerAmount"]),
+            0.56,
+        )
+
+    def test_create_market_order_sell_0_001(self):
+        builder = OrderBuilder(signer)
+
+        signed_order = builder.create_market_order(
+            order_args=MarketOrderArgs(
+                side=SELL,
+                token_id="123",
+                price=0.056,
+                amount=100,
+                fee_rate_bps=111,
+                nonce=123,
+            ),
+            options=CreateOrderOptions(tick_size="0.001", neg_risk=False),
+        )
+
+        self.assertTrue(isinstance(signed_order.order["salt"], int))
+        self.assertIsNotNone(signed_order)
+        self.assertEqual(
+            signed_order.order["maker"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["signer"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["taker"],
+            "0x0000000000000000000000000000000000000000",
+        )
+        self.assertEqual(
+            signed_order.order["tokenId"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["makerAmount"],
+            100000000,
+        )
+        self.assertEqual(
+            signed_order.order["takerAmount"],
+            5600000,
+        )
+        self.assertEqual(
+            signed_order.order["side"],
+            1,
+        )
+        self.assertEqual(
+            signed_order.order["expiration"],
+            0,
+        )
+        self.assertEqual(
+            signed_order.order["nonce"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["feeRateBps"],
+            111,
+        )
+        self.assertEqual(
+            signed_order.order["signatureType"],
+            EOA,
+        )
+        self.assertIsNotNone(signed_order.signature)
+        self.assertGreaterEqual(
+            float(signed_order.order["takerAmount"])
+            / float(signed_order.order["makerAmount"]),
+            0.056,
+        )
+
+    def test_create_market_order_sell_0_0001(self):
+        builder = OrderBuilder(signer)
+
+        signed_order = builder.create_market_order(
+            order_args=MarketOrderArgs(
+                side=SELL,
+                token_id="123",
+                price=0.0056,
+                amount=100,
+                fee_rate_bps=111,
+                nonce=123,
+            ),
+            options=CreateOrderOptions(tick_size="0.0001", neg_risk=False),
+        )
+
+        self.assertTrue(isinstance(signed_order.order["salt"], int))
+        self.assertIsNotNone(signed_order)
+        self.assertEqual(
+            signed_order.order["maker"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["signer"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["taker"],
+            "0x0000000000000000000000000000000000000000",
+        )
+        self.assertEqual(
+            signed_order.order["tokenId"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["makerAmount"],
+            100000000,
+        )
+        self.assertEqual(
+            signed_order.order["takerAmount"],
+            560000,
+        )
+        self.assertEqual(
+            signed_order.order["side"],
+            1,
+        )
+        self.assertEqual(
+            signed_order.order["expiration"],
+            0,
+        )
+        self.assertEqual(
+            signed_order.order["nonce"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["feeRateBps"],
+            111,
+        )
+        self.assertEqual(
+            signed_order.order["signatureType"],
+            EOA,
+        )
+        self.assertIsNotNone(signed_order.signature)
+        self.assertGreaterEqual(
+            float(signed_order.order["takerAmount"])
+            / float(signed_order.order["makerAmount"]),
+            0.0056,
+        )
+
+    def test_create_market_order_sell_0_1_neg_risk(self):
+        builder = OrderBuilder(signer)
+
+        signed_order = builder.create_market_order(
+            order_args=MarketOrderArgs(
+                side=SELL,
+                token_id="123",
+                price=0.5,
+                amount=100,
+                fee_rate_bps=111,
+                nonce=123,
+            ),
+            options=CreateOrderOptions(tick_size="0.1", neg_risk=True),
+        )
+
+        self.assertTrue(isinstance(signed_order.order["salt"], int))
+        self.assertIsNotNone(signed_order)
+        self.assertEqual(
+            signed_order.order["maker"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["signer"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["taker"],
+            "0x0000000000000000000000000000000000000000",
+        )
+        self.assertEqual(
+            signed_order.order["tokenId"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["makerAmount"],
+            100000000,
+        )
+        self.assertEqual(
+            signed_order.order["takerAmount"],
+            50000000,
+        )
+        self.assertEqual(
+            signed_order.order["side"],
+            1,
+        )
+        self.assertEqual(
+            signed_order.order["expiration"],
+            0,
+        )
+        self.assertEqual(
+            signed_order.order["nonce"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["feeRateBps"],
+            111,
+        )
+        self.assertEqual(
+            signed_order.order["signatureType"],
+            EOA,
+        )
+        self.assertIsNotNone(signed_order.signature)
+        self.assertGreaterEqual(
+            float(signed_order.order["takerAmount"])
+            / float(signed_order.order["makerAmount"]),
+            0.5,
+        )
+
+    def test_create_market_order_sell_0_01_neg_risk(self):
+        builder = OrderBuilder(signer)
+
+        signed_order = builder.create_market_order(
+            order_args=MarketOrderArgs(
+                side=SELL,
+                token_id="123",
+                price=0.56,
+                amount=100,
+                fee_rate_bps=111,
+                nonce=123,
+            ),
+            options=CreateOrderOptions(tick_size="0.01", neg_risk=True),
+        )
+
+        self.assertTrue(isinstance(signed_order.order["salt"], int))
+        self.assertIsNotNone(signed_order)
+        self.assertEqual(
+            signed_order.order["maker"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["signer"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["taker"],
+            "0x0000000000000000000000000000000000000000",
+        )
+        self.assertEqual(
+            signed_order.order["tokenId"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["makerAmount"],
+            100000000,
+        )
+        self.assertEqual(
+            signed_order.order["takerAmount"],
+            56000000,
+        )
+        self.assertEqual(
+            signed_order.order["side"],
+            1,
+        )
+        self.assertEqual(
+            signed_order.order["expiration"],
+            0,
+        )
+        self.assertEqual(
+            signed_order.order["nonce"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["feeRateBps"],
+            111,
+        )
+        self.assertEqual(
+            signed_order.order["signatureType"],
+            EOA,
+        )
+        self.assertIsNotNone(signed_order.signature)
+        self.assertGreaterEqual(
+            float(signed_order.order["takerAmount"])
+            / float(signed_order.order["makerAmount"]),
+            0.56,
+        )
+
+    def test_create_market_order_sell_0_001_neg_risk(self):
+        builder = OrderBuilder(signer)
+
+        signed_order = builder.create_market_order(
+            order_args=MarketOrderArgs(
+                side=SELL,
+                token_id="123",
+                price=0.056,
+                amount=100,
+                fee_rate_bps=111,
+                nonce=123,
+            ),
+            options=CreateOrderOptions(tick_size="0.001", neg_risk=True),
+        )
+
+        self.assertTrue(isinstance(signed_order.order["salt"], int))
+        self.assertIsNotNone(signed_order)
+        self.assertEqual(
+            signed_order.order["maker"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["signer"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["taker"],
+            "0x0000000000000000000000000000000000000000",
+        )
+        self.assertEqual(
+            signed_order.order["tokenId"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["makerAmount"],
+            100000000,
+        )
+        self.assertEqual(
+            signed_order.order["takerAmount"],
+            5600000,
+        )
+        self.assertEqual(
+            signed_order.order["side"],
+            1,
+        )
+        self.assertEqual(
+            signed_order.order["expiration"],
+            0,
+        )
+        self.assertEqual(
+            signed_order.order["nonce"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["feeRateBps"],
+            111,
+        )
+        self.assertEqual(
+            signed_order.order["signatureType"],
+            EOA,
+        )
+        self.assertIsNotNone(signed_order.signature)
+        self.assertGreaterEqual(
+            float(signed_order.order["takerAmount"])
+            / float(signed_order.order["makerAmount"]),
+            0.056,
+        )
+
+    def test_create_market_order_sell_0_0001_neg_risk(self):
+        builder = OrderBuilder(signer)
+
+        signed_order = builder.create_market_order(
+            order_args=MarketOrderArgs(
+                side=SELL,
+                token_id="123",
+                price=0.0056,
+                amount=100,
+                fee_rate_bps=111,
+                nonce=123,
+            ),
+            options=CreateOrderOptions(tick_size="0.0001", neg_risk=True),
+        )
+
+        self.assertTrue(isinstance(signed_order.order["salt"], int))
+        self.assertIsNotNone(signed_order)
+        self.assertEqual(
+            signed_order.order["maker"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["signer"],
+            "0xf39Fd6e51aad88F6F4ce6aB8827279cffFb92266",
+        )
+        self.assertEqual(
+            signed_order.order["taker"],
+            "0x0000000000000000000000000000000000000000",
+        )
+        self.assertEqual(
+            signed_order.order["tokenId"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["makerAmount"],
+            100000000,
+        )
+        self.assertEqual(
+            signed_order.order["takerAmount"],
+            560000,
+        )
+        self.assertEqual(
+            signed_order.order["side"],
+            1,
+        )
+        self.assertEqual(
+            signed_order.order["expiration"],
+            0,
+        )
+        self.assertEqual(
+            signed_order.order["nonce"],
+            123,
+        )
+        self.assertEqual(
+            signed_order.order["feeRateBps"],
+            111,
+        )
+        self.assertEqual(
+            signed_order.order["signatureType"],
+            EOA,
+        )
+        self.assertIsNotNone(signed_order.signature)
+        self.assertGreaterEqual(
+            float(signed_order.order["takerAmount"])
+            / float(signed_order.order["makerAmount"]),
+            0.0056,
+        )
